KeyboardTomlConfig

Struct KeyboardTomlConfig 

pub struct KeyboardTomlConfig {
    pub host: Option<HostConfig>,
    pub rmk: RmkConstantsConfig,
    /* private fields */
}
Configurations for RMK keyboard.

Fields

host: Option<HostConfig>

Set host configurations

rmk: RmkConstantsConfig

RMK config constants

Implementations

Source

impl KeyboardTomlConfig

Source

impl KeyboardTomlConfig

Source

impl KeyboardTomlConfig

Source

impl KeyboardTomlConfig

Source

impl KeyboardTomlConfig

Source

impl KeyboardTomlConfig

Source

impl KeyboardTomlConfig

pub fn get_layout_config( &self, ) -> Result<(LayoutConfig, Vec<Vec<KeyInfo>>), String>

Layout is a mandatory field in toml, so we mainly check the sizes

Source

impl KeyboardTomlConfig

Source

impl KeyboardTomlConfig

Source

impl KeyboardTomlConfig

pub fn new_from_toml_path<P: AsRef<Path>>(config_toml_path: P) -> Self

pub fn auto_calculate_parameters(&mut self)

Auto calculate some parameters in toml:

  • Update morse_max_num to fit all configured morses
  • Update max_patterns_per_key to fit the max number of configured (pattern, action) pairs per morse key
  • Update peripheral number based on the number of split boards
  • TODO: Update controller number based on the number of split boards
Source

impl KeyboardTomlConfig