pub struct MorsesConfig {
pub enable_flow_tap: Option<bool>,
pub prior_idle_time: Option<DurationMillis>,
pub unilateral_tap: Option<bool>,
pub permissive_hold: Option<bool>,
pub hold_on_other_press: Option<bool>,
pub normal_mode: Option<bool>,
pub hold_timeout: Option<DurationMillis>,
pub gap_timeout: Option<DurationMillis>,
pub profiles: Option<HashMap<String, MorseProfile>>,
pub morses: Option<Vec<MorseConfig>>,
}Expand description
Configurations for morse keys
Fields
enable_flow_tap: Option<bool>prior_idle_time: Option<DurationMillis>used in permissive_hold mode
unilateral_tap: Option<bool>if true, tap-hold key will always send tap action when tapped with the same hand only
permissive_hold: Option<bool>The decision mode of the morse/tap-hold key (only one of permissive_hold, hold_on_other_press and normal_mode can be true) if none of them is given, normal mode will be the default
hold_on_other_press: Option<bool>normal_mode: Option<bool>hold_timeout: Option<DurationMillis>If the key is pressed longer than this, it is accepted as hold (in milliseconds)
gap_timeout: Option<DurationMillis>The time elapsed from the last release of a key is longer than this, it will break the morse pattern (in milliseconds)
profiles: Option<HashMap<String, MorseProfile>>these can be used to overrides the defaults given above
morses: Option<Vec<MorseConfig>>the definition of morse / tap dance keys