pub struct KeyboardTomlConfig {
pub host: Option<HostConfig>,
pub rmk: RmkConstantsConfig,
/* private fields */
}Expand description
Configurations for RMK keyboard.
Fields
host: Option<HostConfig>Set host configurations
rmk: RmkConstantsConfigRMK config constants
Implementations
Sourceimpl KeyboardTomlConfig
impl KeyboardTomlConfig
pub fn get_chip_model(&self) -> Result<ChipModel, String>
pub fn get_chip_config(&self) -> ChipConfig
Sourceimpl KeyboardTomlConfig
impl KeyboardTomlConfig
pub fn get_communication_config(&self) -> Result<CommunicationConfig, String>
Sourceimpl KeyboardTomlConfig
impl KeyboardTomlConfig
pub fn get_device_config(&self) -> Basic
pub fn get_dependency_config(&self) -> DependencyConfig
Sourceimpl KeyboardTomlConfig
impl KeyboardTomlConfig
pub fn get_behavior_config(&self) -> Result<BehaviorConfig, String>
Sourceimpl KeyboardTomlConfig
impl KeyboardTomlConfig
pub fn get_board_config(&self) -> Result<BoardConfig, String>
Sourceimpl KeyboardTomlConfig
impl KeyboardTomlConfig
pub fn get_host_config(&self) -> HostConfig
Sourceimpl KeyboardTomlConfig
impl KeyboardTomlConfig
Sourcepub fn get_layout_config(
&self,
) -> Result<(LayoutConfig, Vec<Vec<KeyInfo>>), String>
pub fn get_layout_config( &self, ) -> Result<(LayoutConfig, Vec<Vec<KeyInfo>>), String>
Layout is a mandatory field in toml, so we mainly check the sizes
Sourceimpl KeyboardTomlConfig
impl KeyboardTomlConfig
pub fn get_light_config(&self) -> LightConfig
Sourceimpl KeyboardTomlConfig
impl KeyboardTomlConfig
pub fn get_storage_config(&self) -> StorageConfig
Sourceimpl KeyboardTomlConfig
impl KeyboardTomlConfig
pub fn new_from_toml_path<P: AsRef<Path>>(config_toml_path: P) -> Self
Sourcepub fn auto_calculate_parameters(&mut self)
pub fn auto_calculate_parameters(&mut self)
Auto calculate some parameters in toml:
- Update morse_max_num to fit all configured morses
- Update max_patterns_per_key to fit the max number of configured (pattern, action) pairs per morse key
- Update peripheral number based on the number of split boards
- TODO: Update controller number based on the number of split boards
Sourceimpl KeyboardTomlConfig
impl KeyboardTomlConfig
pub fn get_output_config(&self) -> Result<Vec<OutputConfig>, String>